@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014, 2015, 2016, 2017 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014, 2015, 2016, 2017, 2018 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2017 Jan Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -22,17 +22,29 @@
 ;;; tool.
 ;;;
 
-;; Attempt to use our very own Guix modules.
-(eval-when (compile load eval)
+(use-modules (system base compile))
 
-  ;; Ignore any available .go, and force recompilation.  This is because our
-  ;; checkout in the store has mtime set to the epoch, and thus .go files look
-  ;; newer, even though they may not correspond.
+(eval-when (expand load eval)
+
+  ;; Pre-load the compiler so we don't end up auto-compiling it.
+  (compile #t)
+
+  ;; Use our very own Guix modules.
   (set! %fresh-auto-compile #t)
 
+  ;; Ignore .go files except for Guile's.  This is because our checkout in the
+  ;; store has mtime set to the epoch, and thus .go files look newer, even
+  ;; though they may not correspond.  Use 'reverse' so that /gnu/store/…-guile
+  ;; comes before /run/current-system/profile.
+  (set! %load-compiled-path
+    (list
+     (dirname (dirname (search-path (reverse %load-compiled-path)
+                                    "ice-9/boot-9.go")))))
+
   (and=> (assoc-ref (current-source-location) 'filename)
          (lambda (file)
-           (let ((dir (string-append (dirname file) "/../..")))
+           (let ((dir (canonicalize-path
+                       (string-append (dirname file) "/../.."))))
              (format (current-error-port) "prepending ~s to the load path~%"
                      dir)
              (set! %load-path (cons dir %load-path))))))
@@ -49,6 +61,8 @@
              ((guix scripts system) #:select (read-operating-system))
              ((guix scripts pack)
               #:select (lookup-compressor self-contained-tarball))
+             (gnu bootloader)
+             (gnu bootloader u-boot)
              (gnu packages)
              (gnu packages gcc)
              (gnu packages base)
@@ -133,7 +147,10 @@ SYSTEM."
     "i686-w64-mingw32"))
 
 (define %guixsd-supported-systems
-  '("x86_64-linux" "i686-linux"))
+  '("x86_64-linux" "i686-linux" "armhf-linux"))
+
+(define %u-boot-systems
+  '("armhf-linux"))
 
 (define (qemu-jobs store system)
   "Return a list of jobs that build QEMU images for SYSTEM."
@@ -157,20 +174,32 @@ system.")
     (expt 2 20))
 
   (if (member system %guixsd-supported-systems)
-      (list (->job 'usb-image
-                   (run-with-store store
-                     (mbegin %store-monad
-                       (set-guile-for-build (default-guile))
-                       (system-disk-image installation-os
-                                          #:disk-image-size
-                                          (* 1024 MiB)))))
-            (->job 'iso9660-image
-                   (run-with-store store
-                     (mbegin %store-monad
-                       (set-guile-for-build (default-guile))
-                       (system-disk-image installation-os
-                                          #:file-system-type
-                                          "iso9660")))))
+      (if (member system %u-boot-systems)
+          (list (->job 'flash-image
+                       (run-with-store store
+                         (mbegin %store-monad
+                           (set-guile-for-build (default-guile))
+                           (system-disk-image
+                            (operating-system (inherit installation-os)
+                             (bootloader (bootloader-configuration
+                                          (bootloader u-boot-bootloader)
+                                          (target #f))))
+                            #:disk-image-size
+                            (* 1024 MiB))))))
+          (list (->job 'usb-image
+                       (run-with-store store
+                         (mbegin %store-monad
+                           (set-guile-for-build (default-guile))
+                           (system-disk-image installation-os
+                                              #:disk-image-size
+                                              (* 1024 MiB)))))
+                (->job 'iso9660-image
+                       (run-with-store store
+                         (mbegin %store-monad
+                           (set-guile-for-build (default-guile))
+                           (system-disk-image installation-os
+                                              #:file-system-type
+                                              "iso9660"))))))
       '()))
 
 (define (system-test-jobs store system)
@@ -236,7 +265,8 @@ all its dependencies, and ready to be installed on non-GuixSD distributions.")
 
 (define job-name
   ;; Return the name of a package's job.
-  (compose string->symbol package-full-name))
+  (compose string->symbol
+           (cut package-full-name <> "-")))
 
 (define package->job
   (let ((base-packages
@@ -295,6 +325,12 @@ valid."
       (((? string?) (? string?) ...) 'list)       ; only build selected list of packages
       (_ 'all)))                                  ; build everything
 
+  (define systems
+    (match (assoc-ref arguments 'systems)
+      (#f              %hydra-supported-systems)
+      ((lst ...)       lst)
+      ((? string? str) (call-with-input-string str read))))
+
   (define (cross-jobs system)
     (define (from-32-to-64? target)
       ;; Return true if SYSTEM is 32-bit and TARGET is 64-bit.  This hack
@@ -315,8 +351,15 @@ valid."
 
     (define (pointless? target)
       ;; Return #t if it makes no sense to cross-build to TARGET from SYSTEM.
-      (and (string-contains target "mingw")
-           (not (string=? "x86_64-linux" system))))
+      (match system
+        ((or "x86_64-linux" "i686-linux")
+         (if (string-contains target "mingw")
+             (not (string=? "x86_64-linux" system))
+             #f))
+        (_
+         ;; Don't try to cross-compile from non-Intel platforms: this isn't
+         ;; very useful and these are often brittle configurations.
+         #t)))
 
     (define (either proc1 proc2 proc3)
       (lambda (x)
@@ -334,6 +377,13 @@ valid."
   (parameterize ((%graft? #f))
     ;; Return one job for each package, except bootstrap packages.
     (append-map (lambda (system)
+                  (format (current-error-port)
+                          "evaluating for '~a' (heap size: ~a MiB)...~%"
+                          system
+                          (round
+                           (/ (assoc-ref (gc-stats) 'heap-size)
+                              (expt 2. 20))))
+                  (invalidate-derivation-caches!)
                   (case subset
                     ((all)
                      ;; Build everything, including replacements.
@@ -371,4 +421,4 @@ valid."
                          '()))
                     (else
                      (error "unknown subset" subset))))
-                %hydra-supported-systems)))
+                systems)))
