@@ -1,18 +1,20 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013, 2014, 2015, 2016 Ludovic Courtès <ludo@gnu.org>
-;;; Copyright © 2013, 2015 Andreas Enge <andreas@enge.fr>
+;;; Copyright © 2012, 2013, 2014, 2015, 2016, 2017, 2018 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2015, 2018 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
 ;;; Copyright © 2014, 2015, 2016 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2015 Paul van der Walt <paul@denknerd.org>
-;;; Copyright © 2015, 2016, 2017 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2015, 2016, 2017, 2018 Efraim Flashner <efraim@flashner.co.il>
 ;;; Copyright © 2015, 2016, 2017 Ricardo Wurmus <rekado@elephly.net>
 ;;; Copyright © 2016 Christopher Allan Webber <cwebber@dustycloud.org>
-;;; Copyright © 2016, 2017 ng0 <ng0@infotropique.org>
+;;; Copyright © 2016, 2017 Nils Gillmann <ng0@n0.is>
 ;;; Copyright © 2016 Christopher Baines <mail@cbaines.net>
 ;;; Copyright © 2016 Mike Gerwitz <mtg@gnu.org>
 ;;; Copyright © 2016 Troy Sankey <sankeytms@gmail.com>
 ;;; Copyright © 2017 Leo Famulari <leo@famulari.name>
 ;;; Copyright © 2017 Petter <petter@mykolab.ch>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2018 Marius Bakke <mbakke@fastmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -37,6 +39,7 @@
   #:use-module (gnu packages base)
   #:use-module (gnu packages curl)
   #:use-module (gnu packages crypto)
+  #:use-module (gnu packages emacs)
   #:use-module (gnu packages openldap)
   #:use-module (gnu packages perl)
   #:use-module (gnu packages perl-check)
@@ -67,7 +70,7 @@
 (define-public libgpg-error
   (package
     (name "libgpg-error")
-    (version "1.27")
+    (version "1.28")
     (source
      (origin
       (method url-fetch)
@@ -75,7 +78,8 @@
                           version ".tar.bz2"))
       (sha256
        (base32
-        "1li95ni122fzinzlmxbln63nmgij63irxfvi52ws4zfbzv3am4sg"))))
+        "0jfsfnh9bxlxiwxws60yah4ybjw2hshmvqp31pri4m4h8ivrbnry"))
+      (patches (search-patches "libgpg-error-aarch64-logging-fix.patch"))))
     (build-system gnu-build-system)
     (home-page "https://gnupg.org")
     (synopsis "Library of error values for GnuPG components")
@@ -88,18 +92,32 @@ Daemon and possibly more in the future.")
     (properties '((ftp-server . "ftp.gnupg.org")
                   (ftp-directory . "/gcrypt/libgpg-error")))))
 
+;; Some packages (e.g. GPGME) require a newer libgpg-error to deal with
+;; error codes from recent GnuPG.  Remove this in the next rebuild cycle.
+(define-public libgpg-error-1.31
+  (package
+    (inherit libgpg-error)
+    (version "1.31")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnupg/libgpg-error/libgpg-error-"
+                                  version ".tar.bz2"))
+              (sha256
+               (base32
+                "1vx4nw6rxh2biy3h8n96fyr86q29h8gjl6837437i51jr4isil20"))))))
+
 (define-public libgcrypt
   (package
     (replacement libgcrypt/fixed)
     (name "libgcrypt")
-    (version "1.7.8")
+    (version "1.8.2")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnupg/libgcrypt/libgcrypt-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "16f1rsv4y4w2pk1il2jbcqggsb6mrlfva5vayd205fp68zm7d0ll"))))
+               "01sca9m8hm6b5v8hmqsfdjhyz013869p1f0fxw9ln52qfnp4q1n8"))))
     (build-system gnu-build-system)
     (propagated-inputs
      `(("libgpg-error-host" ,libgpg-error)))
@@ -128,19 +146,20 @@ generation.")
 (define libgcrypt/fixed
   (package
     (inherit libgcrypt)
-    (version "1.8.1")
+    (name "libgcrypt")
+    (version "1.8.3")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnupg/libgcrypt/libgcrypt-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "1cvqd9jk5qshbh48yh3ixw4zyr4n5k50r3475rrh20xfn7w7aa3s"))))))
+               "0z5gs1khzyknyfjr19k8gk4q148s6q987ya85cpn0iv70fz91v36"))))))
 
 (define-public libassuan
   (package
     (name "libassuan")
-    (version "2.4.4")
+    (version "2.5.1")
     (source
      (origin
       (method url-fetch)
@@ -148,10 +167,11 @@ generation.")
                           version ".tar.bz2"))
       (sha256
        (base32
-        "18bwffjkx9pn0lawbsn6zhd90i7xhjgpf9b0nl5xw9134w1a2scy"))))
+        "0jb4nb4nrjr949gd3lw8lh4v5d6qigxaq6xwy24w5apjnhvnrya7"))))
     (build-system gnu-build-system)
     (propagated-inputs
-     `(("libgpg-error" ,libgpg-error) ("pth" ,pth)))
+     `(("libgpg-error" ,libgpg-error)
+       ("pth" ,pth)))
     (home-page "https://gnupg.org")
     (synopsis
      "IPC library used by GnuPG and related software")
@@ -225,21 +245,19 @@ compatible to GNU Pth.")
 (define-public gnupg
   (package
     (name "gnupg")
-    (version "2.2.3")
+    (version "2.2.8")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnupg/gnupg/gnupg-" version
                                   ".tar.bz2"))
               (sha256
                (base32
-                "1d4482c4pbi0p1k8cc0f9c4q51k56v8navrbz5samxrrs42p3lyb"))))
+                "1k8dnnfs9888yp713l7kg2jg110lw47s4krx0njna6fjrsw4qyvp"))))
     (build-system gnu-build-system)
     (native-inputs
      `(("pkg-config" ,pkg-config)))
     (inputs
-     `(("bzip2" ,bzip2)
-       ("curl" ,curl)
-       ("gnutls" ,gnutls)
+     `(("gnutls" ,gnutls)
        ("libassuan" ,libassuan)
        ("libgcrypt" ,libgcrypt)
        ("libgpg-error" ,libgpg-error)
@@ -340,18 +358,19 @@ libskba (working with X.509 certificates and CMS data).")
                 ;; Keep the old name around to ease transition.
                 (symlink "gpgv" "gpgv2")
                 (symlink "gpg" "gpg2")
-                #t)))))))))
+                #t)))))))
+   (properties `((superseded . ,gnupg)))))
 
 (define-public gnupg-1
   (package (inherit gnupg)
-    (version "1.4.22")
+    (version "1.4.23")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnupg/gnupg/gnupg-" version
                                   ".tar.bz2"))
               (sha256
                (base32
-                "1d1hz4szh1kvwhsw7w2zxa6q5ndrk3qy6hj289l1b8k3xi5s554m"))))
+                "1fkq4sqldvf6a25mm2qz95swv1qjg464736091w51djiwqbjyin9"))))
     (native-inputs '())
     (inputs
      `(("zlib" ,zlib)
@@ -365,12 +384,13 @@ libskba (working with X.509 certificates and CMS data).")
          (add-after 'unpack 'patch-check-sh
            (lambda _
              (substitute* "checks/Makefile.in"
-               (("/bin/sh") (which "sh"))))))))))
+               (("/bin/sh") (which "sh")))
+             #t)))))))
 
 (define-public gpgme
   (package
     (name "gpgme")
-    (version "1.9.0")
+    (version "1.11.1")
     (source
      (origin
       (method url-fetch)
@@ -378,23 +398,15 @@ libskba (working with X.509 certificates and CMS data).")
                           ".tar.bz2"))
       (sha256
        (base32
-        "1ssc0gs02r4fasabk7c6v6r865k2j02mpb5g1vkpbmzsigdzwa8v"))))
+        "0vxx5xaag3rhp4g2arp5qm77gvz4kj0m3hnpvhkdvqyjfhbi26rd"))))
     (build-system gnu-build-system)
+    (native-inputs
+     `(("gnupg" ,gnupg)))
     (propagated-inputs
      ;; Needs to be propagated because gpgme.h includes gpg-error.h.
-     `(("libgpg-error" ,libgpg-error)))
+     `(("libgpg-error" ,libgpg-error-1.31)))
     (inputs
-     `(("gnupg" ,gnupg-2.0)
-       ("libassuan" ,libassuan)))
-    (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-after 'configure 'patch-cmake-file
-           (lambda _
-             ;; Work around <https://bugs.gnupg.org/gnupg/issue2877>.
-             (substitute* "lang/cpp/src/GpgmeppConfig.cmake.in"
-               (("@libsuffix@") ".so"))
-             #t)))))
+     `(("libassuan" ,libassuan)))
     (home-page "https://www.gnupg.org/related_software/gpgme/")
     (synopsis "Library providing simplified access to GnuPG functionality")
     (description
@@ -426,7 +438,8 @@ and every application benefits from this.")
              (chdir "lang/qt")
              #t)))))
     (native-inputs
-     `(("pkg-config" ,pkg-config)))
+     `(("pkg-config" ,pkg-config)
+       ,@(package-native-inputs gpgme)))
     (inputs
      `(("gpgme" ,gpgme)
        ("qtbase" ,qtbase)
@@ -491,9 +504,10 @@ distributed separately.")
            (lambda _
              (zero? (system* "make" "check")))))))
     (build-system python-build-system)
+    (native-inputs
+     `(("gnupg" ,gnupg-1)))
     (inputs
-     `(("gnupg" ,gnupg-2.0)
-       ("gpgme" ,gpgme)))
+     `(("gpgme" ,gpgme)))
     (home-page "https://launchpad.net/pygpgme")
     (synopsis "Python module for working with OpenPGP messages")
     (description
@@ -507,14 +521,14 @@ decrypt messages using the OpenPGP format by making use of GPGME.")
 (define-public python-gnupg
   (package
     (name "python-gnupg")
-    (version "0.3.8")
+    (version "0.4.3")
     (source
      (origin
        (method url-fetch)
        (uri (pypi-uri "python-gnupg" version))
        (sha256
         (base32
-         "0nkbs9c8f30lra7ca39kg91x8cyxn0jb61vih4qky839gpbwwwiq"))))
+         "03dc8whhvk7ccspbk8vzfhkxli8cd9zfbss5p597g4jldgy8s59d"))))
     (build-system python-build-system)
     (arguments
      `(#:phases
@@ -522,16 +536,14 @@ decrypt messages using the OpenPGP format by making use of GPGME.")
          (replace 'check
            (lambda _
              (substitute* "test_gnupg.py"
-               ;; Exported keys don't have a version line!
-               (("del k1\\[1\\]") "#")
                ;; Unsure why this test fails.
                (("'test_search_keys'") "True")
                (("def test_search_keys") "def disabled__search_keys"))
              (setenv "USERNAME" "guixbuilder")
              ;; The doctests are extremely slow and sometimes time out,
              ;; so we disable them.
-             (zero? (system* "python"
-                             "test_gnupg.py" "--no-doctests")))))))
+             (invoke "python"
+                     "test_gnupg.py" "--no-doctests"))))))
     (native-inputs
      `(("gnupg" ,gnupg-1)))
     (home-page "https://packages.python.org/python-gnupg/index.html")
@@ -584,7 +596,7 @@ signing, decryption, verification, and key-listing parsing.")
 (define-public pius
   (package
    (name "pius")
-   (version "2.2.4")
+   (version "2.2.6")
    (source (origin
             (method url-fetch)
             (uri (string-append
@@ -592,10 +604,12 @@ signing, decryption, verification, and key-listing parsing.")
                   version "/pius-" version ".tar.bz2"))
             (sha256
              (base32
-              "0lgc0ipwdfqbq16zax8kn17wbv8xyw4ygc09fawl2yp459z0ql4n"))))
+              "1893hzpx3zv724drqv48csrn0cm98xw4ymb1zmhs2jvjj1778zfj"))
+            (patches (search-patches "pius.patch"))))
    (build-system python-build-system)
    (inputs `(("perl" ,perl)                ;for 'pius-party-worksheet'
-             ("gpg" ,gnupg)))
+             ("gpg" ,gnupg)
+             ("python-six" ,python2-six)))
    (arguments
     `(#:tests? #f
       #:python ,python-2                     ;uses the Python 2 'print' syntax
@@ -623,84 +637,87 @@ PGP keysigning parties.")
    (home-page "https://www.phildev.net/pius/index.shtml")))
 
 (define-public signing-party
-  (package
-   (name "signing-party")
-   (version "2.6")
-   (source (origin
-            (method url-fetch)
-            (uri (string-append "mirror://debian/pool/main/s/signing-party/"
-                                "signing-party_" version ".orig.tar.gz"))
-            (sha256 (base32
-                     "1n5bpcfpl9vg1xp6r1jhbyahrgdyxp05b5pria1rh4m0qnv8sifr"))))
-   (build-system gnu-build-system)
-   (native-inputs
-    `(("autoconf" ,(autoconf-wrapper))
-      ("automake" ,automake)))
-   (inputs `(("perl" ,perl)
-             ("perl-text-template" ,perl-text-template)
-             ("perl-mime-tools" ,perl-mime-tools)
-             ("perl-gnupg-interface" ,perl-gnupg-interface)
-             ("perl-net-idn-encode" ,perl-net-idn-encode)
-             ("libmd" ,libmd)))
-   (arguments
-    `(#:tests? #f
-      #:phases
-      (modify-phases %standard-phases
-        (add-before 'configure 'change-directory
-          (lambda _
-            ;; The build system in the unpack phase changes to a less useful
-            ;; subdirectory, so move up one level
-            (chdir (dirname (getcwd)))))
-        (replace 'configure
-          (lambda* (#:key outputs #:allow-other-keys)
-            (let ((out (assoc-ref outputs "out")))
-              (substitute* "keyanalyze/Makefile"
-                (("LDLIBS") (string-append "CC=" (which "gcc") "\nLDLIBS")))
-              (substitute* "keyanalyze/Makefile"
-                (("\\./configure") (string-append "./configure --prefix=" out)))
-              (substitute* "gpgwrap/src/Makefile"
-                (("\\} clean")
-                 (string-append "} clean\ninstall:\n\tinstall -D bin/gpgwrap "
-                                out "/bin/gpgwrap\n")))
-              (substitute* '("gpgsigs/Makefile" "keyanalyze/Makefile"
-                             "keylookup/Makefile" "sig2dot/Makefile"
-                             "springgraph/Makefile")
-                (("/usr") out))
-              (setenv "CONFIG_SHELL" (which "sh")))))
-        (replace 'install
-          (lambda* (#:key outputs #:allow-other-keys #:rest args)
-            (let ((out (assoc-ref outputs "out"))
-                  (install (assoc-ref %standard-phases 'install)))
-              (apply install args)
-              (for-each
-                (lambda (dir file)
-                  (copy-file (string-append dir "/" file)
-                             (string-append out "/bin/" file)))
-                '("caff" "caff" "caff" "gpgdir" "gpg-key2ps"
-                  "gpglist" "gpg-mailkeys" "gpgparticipants")
-                '("caff" "pgp-clean" "pgp-fixkey" "gpgdir" "gpg-key2ps"
-                  "gpglist" "gpg-mailkeys" "gpgparticipants"))
-              (for-each
-                (lambda (dir file)
-                  (copy-file (string-append dir "/" file)
-                             (string-append out "/share/man/man1/" file)))
-                '("caff" "caff" "caff" "gpgdir"
-                  "gpg-key2ps" "gpglist" "gpg-mailkeys"
-                  "gpgparticipants" "gpgsigs" "gpgwrap/doc"
-                  "keyanalyze" "keyanalyze/pgpring" "keyanalyze")
-                '("caff.1" "pgp-clean.1" "pgp-fixkey.1" "gpgdir.1"
-                  "gpg-key2ps.1" "gpglist.1" "gpg-mailkeys.1"
-                  "gpgparticipants.1" "gpgsigs.1" "gpgwrap.1"
-                  "process_keys.1" "pgpring.1" "keyanalyze.1")))))
-        (add-after 'install 'wrap-programs
-          (lambda* (#:key outputs #:allow-other-keys)
-            (let* ((out (assoc-ref outputs "out")))
-              (wrap-program
-                  (string-append out "/bin/caff")
-                `("PERL5LIB" ":" prefix (,(getenv "PERL5LIB"))))))))))
-   (synopsis "Collection of scripts for simplifying gnupg key signing")
-   (description
-    "Signing-party is a collection for all kinds of PGP/GnuPG related things,
+  ;; Upstream moved from alioth.debian.org to salsa.debian.org but the
+  ;; automatic svn import did not preserve tags apparently, so there's no real
+  ;; version number.
+  (let ((commit "d6f2296325605ee96ddf9f5b156e5e3f667a6df3")
+        (revision "0"))
+    (package
+      (name "signing-party")
+      (version (git-version "2.6" revision commit))
+      (home-page "https://salsa.debian.org/stappers/pgp-tools")
+      (source (origin
+                (method git-fetch)
+                (uri (git-reference
+                      (url home-page)
+                      (commit commit)))
+                (sha256
+                 (base32
+                  "00f7zasbwcbjzd92br2j10pyjxv0aw1qb4540qfz2dxzxgmdscrz"))))
+      (build-system gnu-build-system)
+      (native-inputs
+       `(("autoconf" ,autoconf-wrapper)
+         ("automake" ,automake)))
+      (inputs `(("perl" ,perl)
+                ("perl-text-template" ,perl-text-template)
+                ("perl-mime-tools" ,perl-mime-tools)
+                ("perl-gnupg-interface" ,perl-gnupg-interface)
+                ("perl-net-idn-encode" ,perl-net-idn-encode)
+                ("libmd" ,libmd)))
+      (arguments
+       `(#:tests? #f
+         #:phases
+         (modify-phases %standard-phases
+           (replace 'configure
+             (lambda* (#:key outputs #:allow-other-keys)
+               (let ((out (assoc-ref outputs "out")))
+                 (substitute* "keyanalyze/Makefile"
+                   (("LDLIBS") (string-append "CC=" (which "gcc") "\nLDLIBS")))
+                 (substitute* "keyanalyze/Makefile"
+                   (("\\./configure") (string-append "./configure --prefix=" out)))
+                 (substitute* "gpgwrap/Makefile"
+                   (("\\} clean")
+                    (string-append "} clean\ninstall:\n\tinstall -D bin/gpgwrap "
+                                   out "/bin/gpgwrap\n")))
+                 (substitute* '("gpgsigs/Makefile" "keyanalyze/Makefile"
+                                "keylookup/Makefile" "sig2dot/Makefile"
+                                "springgraph/Makefile")
+                   (("/usr") out))
+                 (setenv "CONFIG_SHELL" (which "sh")))))
+           (replace 'install
+             (lambda* (#:key outputs #:allow-other-keys #:rest args)
+               (let ((out (assoc-ref outputs "out"))
+                     (install (assoc-ref %standard-phases 'install)))
+                 (apply install args)
+                 (for-each
+                  (lambda (dir file)
+                    (copy-file (string-append dir "/" file)
+                               (string-append out "/bin/" file)))
+                  '("caff" "caff" "caff" "gpgdir" "gpg-key2ps"
+                    "gpglist" "gpg-mailkeys" "gpgparticipants")
+                  '("caff" "pgp-clean" "pgp-fixkey" "gpgdir" "gpg-key2ps"
+                    "gpglist" "gpg-mailkeys" "gpgparticipants"))
+                 (for-each
+                  (lambda (dir file)
+                    (copy-file (string-append dir "/" file)
+                               (string-append out "/share/man/man1/" file)))
+                  '("caff" "caff" "caff" "gpgdir"
+                    "gpg-key2ps" "gpglist" "gpg-mailkeys"
+                    "gpgparticipants" "gpgsigs" "gpgwrap/doc"
+                    "keyanalyze" "keyanalyze/pgpring" "keyanalyze")
+                  '("caff.1" "pgp-clean.1" "pgp-fixkey.1" "gpgdir.1"
+                    "gpg-key2ps.1" "gpglist.1" "gpg-mailkeys.1"
+                    "gpgparticipants.1" "gpgsigs.1" "gpgwrap.1"
+                    "process_keys.1" "pgpring.1" "keyanalyze.1")))))
+           (add-after 'install 'wrap-programs
+             (lambda* (#:key outputs #:allow-other-keys)
+               (let* ((out (assoc-ref outputs "out")))
+                 (wrap-program
+                     (string-append out "/bin/caff")
+                   `("PERL5LIB" ":" prefix (,(getenv "PERL5LIB"))))))))))
+      (synopsis "Collection of scripts for simplifying gnupg key signing")
+      (description
+       "Signing-party is a collection for all kinds of PGP/GnuPG related things,
 including tools for signing keys, keyring analysis, and party preparation.
 @enumerate
 @item caff: CA - Fire and Forget signs and mails a key
@@ -718,23 +735,22 @@ including tools for signing keys, keyring analysis, and party preparation.
 @item sig2dot: converts a list of GnuPG signatures to a .dot file
 @item springgraph: creates a graph from a .dot file
 @end enumerate")
-   ;; gpl2+ for almost all programs, except for keyanalyze: gpl2
-   ;; and caff and gpgsigs: bsd-3, see
-   ;; http://packages.debian.org/changelogs/pool/main/s/signing-party/current/copyright
-   (license license:gpl2)
-   (home-page "https://pgp-tools.alioth.debian.org/")))
+      ;; gpl2+ for almost all programs, except for keyanalyze: gpl2
+      ;; and caff and gpgsigs: bsd-3, see
+      ;; http://packages.debian.org/changelogs/pool/main/s/signing-party/current/copyright
+      (license license:gpl2))))
 
 (define-public pinentry-tty
   (package
     (name "pinentry-tty")
-    (version "1.0.0")
+    (version "1.1.0")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnupg/pinentry/pinentry-"
                                   version ".tar.bz2"))
               (sha256
                (base32
-                "0ni7g4plq6x78p32al7m8h2zsakvg1rhfz0qbc3kdc7yq7nw4whn"))))
+                "0w35ypl960pczg5kp6km3dyr000m1hf0vpwwlh72jjkjza36c1v8"))))
     (build-system gnu-build-system)
     (arguments
      `(#:configure-flags '("--enable-pinentry-tty")))
@@ -749,7 +765,20 @@ including tools for signing keys, keyring analysis, and party preparation.
     (description
      "Pinentry provides a console that allows users to enter a passphrase when
 @code{gpg} is run and needs it.")
-    (license license:gpl2+)))
+    (license license:gpl2+)
+    (properties '((ftp-server . "ftp.gnupg.org")
+                  (ftp-directory . "/gcrypt/pinentry")
+                  (upstream-name . "pinentry")))))
+
+(define-public pinentry-emacs
+  (package
+    (inherit pinentry-tty)
+    (name "pinentry-emacs")
+    (arguments
+     `(#:configure-flags '("--enable-pinentry-emacs")))
+    (description
+     "Pinentry provides a console and an Emacs interface that allows users to
+enter a passphrase when required by @code{gpg} or other software.")))
 
 (define-public pinentry-gtk2
   (package
@@ -799,7 +828,7 @@ passphrase when @code{gpg} is run and needs it.")))
 (define-public paperkey
   (package
     (name "paperkey")
-    (version "1.3")
+    (version "1.5")
     (source (origin
               (method url-fetch)
               (uri (string-append "http://www.jabberwocky.com/"
@@ -807,7 +836,7 @@ passphrase when @code{gpg} is run and needs it.")))
                                   version ".tar.gz"))
               (sha256
                (base32
-                "1yybj8bj68v4lxwpn596b6ismh2fyixw5vlqqg26byrn4d9dfmsv"))))
+                "1prd2jaf4zjad3xhv160hmi5n408ssljfg7iz90jxs9w111pjwy4"))))
     (build-system gnu-build-system)
     (arguments
      `(#:phases
@@ -942,3 +971,58 @@ keyring content.  Parcimonie is a daemon that fetches one key at a time using
 the Tor network, waits a bit, changes the Tor circuit being used, and starts
 over.")
     (license license:gpl1+)))
+
+(define-public jetring
+  (package
+    (name "jetring")
+    (version "0.27")
+    (source
+      (origin
+        (method url-fetch)
+        (uri (string-append "mirror://debian/pool/main/j/" name "/"
+                            name "_" version ".tar.xz"))
+        (sha256
+         (base32
+          "0jy0x5zj7v87xgyldlsx1knzp0mv10wzamblrw1b61i2m1ii4pxz"))))
+    (build-system gnu-build-system)
+    (arguments
+     '(#:phases
+       (modify-phases %standard-phases
+         (delete 'configure) ; no configure script
+         (add-before 'install 'hardlink-gnupg
+           (lambda* (#:key inputs #:allow-other-keys)
+             (let ((gpg (string-append (assoc-ref inputs "gnupg")
+                                       "/bin/gpg")))
+               (substitute* (find-files "." "jetring-[[:alpha:]]+$")
+                 (("gpg -") (string-append gpg " -"))
+                 (("\\\"gpg\\\"") (string-append "\"" gpg "\"")))
+               #t)))
+         (replace 'install
+           (lambda* (#:key outputs #:allow-other-keys)
+             (let* ((out (assoc-ref outputs "out"))
+                    (man (string-append out "/share/man")))
+               (for-each (lambda (file)
+                           (install-file file (string-append out "/bin/")))
+                         (find-files "." "jetring-[[:alpha:]]+$"))
+               (for-each (lambda (file)
+                           (install-file file (string-append man "/man1/")))
+                         (find-files "." ".*\\.1$"))
+               (install-file "jetring.7" (string-append man "/man7/"))
+               #t))))
+       #:tests? #f)) ; no test phase
+    (inputs
+     `(("gnupg" ,gnupg)
+       ("perl" ,perl)))
+    (home-page "https://joeyh.name/code/jetring/")
+    (synopsis "GnuPG keyring maintenance using changesets")
+    (description
+     "Jetring is a collection of tools that allow for gpg keyrings to be
+maintained using changesets.  It was developed with the Debian keyring in mind,
+and aims to solve the problem that a gpg keyring is a binary blob that's hard
+for multiple people to collaboratively edit.
+
+With jetring, changesets can be submitted, reviewed to see exactly what they
+will do, applied, and used to build a keyring.  The origin of every change made
+to the keyring is available for auditing, and gpg signatures can be used for
+integrity guarantees.")
+    (license license:gpl2+)))
