@@ -5,6 +5,7 @@
 ;;; Copyright © 2016 Leo Famulari <leo@famulari.name>
 ;;; Copyright © 2016 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2017 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -46,14 +47,14 @@
     ;; The 7 release series has an incompatible API, while the 6 series is still
     ;; maintained. Don't update to 7 until we've made sure that the ImageMagick
     ;; users are ready for the 7-series API.
-    (version "6.9.9-23")
+    (version "6.9.10-3")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://imagemagick/ImageMagick-"
                                  version ".tar.xz"))
              (sha256
               (base32
-               "0cd6zcbcfvznf0i3q4xz1c4wm4cfplg4zc466lvlb1w8qbn25948"))))
+               "0njq3vp0f3d5992jsah5nhbc5id2bnl7myhdw669k0vmc55mmlcj"))))
     (build-system gnu-build-system)
     (arguments
      `(#:configure-flags '("--with-frozenpaths" "--without-gcc-arch")
@@ -76,7 +77,8 @@
                         (let ((doc (assoc-ref outputs "doc")))
                           (string-append "DOCUMENTATION_PATH = "
                                          doc "/share/doc/"
-                                         ,name "-" ,version "\n"))))))
+                                         ,name "-" ,version "\n"))))
+                     #t))
                   (add-before
                    'configure 'strip-configure-xml
                    (lambda _
@@ -86,7 +88,8 @@
                        ;; include --docdir, and thus retain a reference to the
                        ;; 'doc' output.
                        (("@CONFIGURE_ARGS@")
-                        "not recorded")))))))
+                        "not recorded"))
+                     #t)))))
     ;; TODO: Add Jasper etc.
     (inputs `(("fftw" ,fftw)
               ("graphviz" ,graphviz)
@@ -143,7 +146,8 @@ text, lines, polygons, ellipses and Bézier curves.")
                 (("my \\$INC_magick = .*")
                  "my $INC_magick = `pkg-config --cflags ImageMagick`;\n")
                 (("my \\$LIBS_magick = .*")
-                 "my $LIBS_magick = `pkg-config --libs ImageMagick`;\n")))))
+                 "my $LIBS_magick = `pkg-config --libs ImageMagick`;\n"))
+              #t)))
          (add-before
           'check 'skip-mpeg-tests
           (lambda _
@@ -151,7 +155,8 @@ text, lines, polygons, ellipses and Bézier curves.")
             ;; MPEG.  Has been reported elsewhere,
             ;; http://www.imagemagick.org/discourse-server/viewtopic.php?f=7&t=25036,
             ;; so skip for now.
-            (delete-file "t/mpeg/read.t"))))))
+            (delete-file "t/mpeg/read.t")
+            #t)))))
     (home-page "http://search.cpan.org/dist/PerlMagick")
     (synopsis "Perl interface to ImageMagick")
     (description "This Perl extension allows the reading, manipulation and
@@ -164,7 +169,7 @@ script.")
 (define-public graphicsmagick
   (package
     (name "graphicsmagick")
-    (version "1.3.26")
+    (version "1.3.29")
     (source (origin
               (method url-fetch)
               (uri
@@ -176,17 +181,7 @@ script.")
                                  "/GraphicsMagick-" version ".tar.xz")))
               (sha256
                (base32
-                "122zgs96dqrys62mnh8x5yvfff6km4d3yrnvaxzg3mg5sprib87v"))
-              (patches
-               (search-patches "graphicsmagick-CVE-2017-11403+CVE-2017-14103.patch"
-                               "graphicsmagick-CVE-2017-12935.patch"
-                               "graphicsmagick-CVE-2017-12936.patch"
-                               "graphicsmagick-CVE-2017-12937.patch"
-                               "graphicsmagick-CVE-2017-13775.patch"
-                               "graphicsmagick-CVE-2017-13776+CVE-2017-13777.patch"
-                               "graphicsmagick-CVE-2017-14042.patch"
-                               "graphicsmagick-CVE-2017-14165.patch"
-                               "graphicsmagick-CVE-2017-14649.patch"))))
+                "1m0cc6kpky06lpcipj7rfwc2jbw2igr0jk97zqmw3j1ld5mg93g1"))))
     (build-system gnu-build-system)
     (arguments
      `(#:configure-flags
