@@ -74,10 +74,10 @@
         (mock ((guix http-client) http-fetch
                (lambda (url . rest)
                  (match url
-                   ("https://api.metacpan.org/release/Foo-Bar"
+                   ("https://fastapi.metacpan.org/v1/release/Foo-Bar"
                     (values (open-input-string test-json)
                             (string-length test-json)))
-                   ("https://api.metacpan.org/module/Test::Script?fields=distribution"
+                   ("https://fastapi.metacpan.org/v1/module/Test::Script?fields=distribution"
                     (let ((result "{ \"distribution\" : \"Test-Script\" }"))
                       (values (open-input-string result)
                               (string-length result))))
@@ -94,13 +94,13 @@
                                ('base32
                                 (? string? hash)))))
                    ('build-system 'perl-build-system)
-                   ('inputs
+                   ('propagated-inputs
                     ('quasiquote
                      (("perl-test-script" ('unquote 'perl-test-script)))))
-                   ('home-page "http://search.cpan.org/dist/Foo-Bar")
+                   ('home-page "http://search.cpan.org/dist/Foo-Bar/")
                    ('synopsis "Fizzle Fuzz")
                    ('description 'fill-in-yourself!)
-                   ('license (package-license perl)))
+                   ('license 'perl-license))
                  (string=? (bytevector->nix-base32-string
                             (call-with-input-string test-source port-sha256))
                            hash))
