@@ -35,6 +35,7 @@
     \"license\": \"MIT/Apache-2.0\",
     \"description\": \"summary\",
     \"homepage\": \"http://example.com\",
+    \"repository\": \"http://example.com\",
   }
 }")
 
@@ -64,7 +65,7 @@
 (test-assert "crate->guix-package"
   ;; Replace network resources with sample data.
   (mock ((guix http-client) http-fetch
-         (lambda (url)
+         (lambda (url . rest)
            (match url
              ("https://crates.io/api/v1/crates/foo"
               (open-input-string test-crate))
@@ -90,7 +91,7 @@
          ('build-system 'cargo-build-system)
          ('inputs
           ('quasiquote
-           (("rust-bar" ('unquote 'rust-bar)))))
+           (("rust-bar" ('unquote 'rust-bar) "src"))))
          ('home-page "http://example.com")
          ('synopsis "summary")
          ('description "summary")
